# Binary set operations

The following table lists all operations that take two set as argument in the
entries.
In the rows we list all set types, both the interfaces (where we abbreviate the
`Abstract` prefix), the basic set types, and the lazy set operations, each
sorted alphabetically.
In the columns we also list the operations, but abbreviated.
The table entries consist of subsets of the following list of operations.
- "⊆" stands for the subset check `issubset`.
- "⊎" stands for the disjointness check `isdisjoint`.
- "∩" stands for the concrete intersection operation `intersection`.
- "C" stands for the conversion operation `convert`.
- "-" indicates that the two types' dimensionality constraints are incompatible.
- A suffix "i" indicates that the operation is inherited from a supertype.


| type ↓ \ type →               |LazyS      |APtop      |ACSym      |ACSPt      |APgon      |AHrec      |AHPgn      |ASing      |Ball1      |Ball2      |BInf       |Ballp      |Ellip      |Empty      |HalfS      |HPgon      |HPhed      |HPtop      |Hplan      |Hrect      |Itrvl      |Line2D       |LineS      |Single     |Universe   |VPgon      |VPtop      |ZeroS      |Zonot      | CP        | CPA       | CH        | CHA       |EMap       | EPM       |Itsct      |ItscA      |LiMap      | MS        | MSA       | CMS       | ReMap     | SIH       | Transl    | UnionSet  | UnionSArr | Complem   |
|-------------------------------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
| **Interfaces**                |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |
| `LazySet`                     |   ⊎       |⊆  ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆  ⊎i      |⊆i ⊎       |⊆i ⊎  ∩    |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆  ⊎       |⊆i ⊎i      |⊆  ⊎       |⊆i ⊎       |⊆i ⊎       |⊆i ⊎i      |⊆i ⊎i      |   ⊎       |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆  ⊎  ∩    |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎  ∩    |   ⊎  ∩    |⊆  ⊎       |
| `APolytope`                   |⊆  ⊎i      |⊆i ⊎i ∩    |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆  ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩    |⊆i ⊎i ∩    |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆  ⊎  ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `ACentrallySymmetric`         |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `ACentrallySymmetricPolytope` |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `APolygon`                    |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |-          |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `AHyperrectangle`             |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆  ⊎  ∩    |⊆i ⊎i ∩i   |⊆i ⊎  ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆  ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `AHPolygon`                   |⊆i ⊎       |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩    |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |-          |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i C |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `ASingleton`                  |⊆  ⊎  ∩    |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆  ⊎  ∩i   |⊆i ⊎i ∩i   |⊆  ⊎  ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆  ⊎  ∩    |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i  ∩i  |⊆i ⊎i  ∩i  |⊆i ⊎i  ∩i  |⊆i ⊎i  ∩i  |⊆i ⊎i  ∩i  |⊆i ⊎i  ∩i  |⊆i ⊎i  ∩i  |⊆i ⊎i  ∩i  |⊆i ⊎i  ∩i  |⊆i ⊎i  ∩i  |⊆i ⊎i  ∩i  |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
|                               |           |           |           |           |           |           |           |           |           |           |           |           |           |           |   ⊎       |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |
| **Basic set types**           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |   ⊎       |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |
| `Ball1`                       |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Ball2`                       |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆  ⊎i ∩i   |⊆i ⊎i      |⊆ ⊎        |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆  ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆  ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `BallInf`                     |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Ballp`                       |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆  ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆  ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆  ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Ellipsoid`                   |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `EmptySet`                    |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆  ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `HalfSpace`                   |   ⊎       |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎       |⊆i ⊎i      |⊆i ⊎i ∩    |⊆i ⊎i ∩    |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎  ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `HPolygon`/`HPolygonOpt`      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i C |⊆i ⊎i ∩i C |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i C |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i   |⊆i ⊎i ∩i C |⊆i ⊎i      |⊆i ⊎i ∩i Ci|-          |⊆i ⊎i      |⊆i ⊎i ∩i C |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i   |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i   |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `HPolyhedron`                 |   ⊎       |⊆i ⊎i ∩  C |   ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|   ⊎i      |⊆i ⊎i ∩i Ci|   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i ∩    |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩    |⊆i ⊎i ∩  Ci|   ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|   ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i   |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩  Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i ∩i Ci|   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `HPolytope`                   |⊆i ⊎       |⊆i ⊎i ∩  C |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i C |⊆i ⊎i ∩i C |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩    |⊆i ⊎i ∩i C |⊆i ⊎i ∩    |⊆i ⊎i ∩  Ci|⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i   |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩  C |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Hyperplane`                  |   ⊎       |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎  ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎       |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Hyperrectangle`              |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i C |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Interval`                    |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |-          |⊆i ⊎i ∩i   |-          |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |-          |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |-          |-          |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |-          |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Line2D`                        |   ⊎       |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |-          |   ⊎i ∩    |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎  ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `LineSegment`                 |⊆  ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆  ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |-          |⊆i ⊎i      |⊆i ⊎  ∩i   |⊆i ⊎i ∩i   |⊆  ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Singleton`                   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Universe`                    |⊆  ⊎  ∩    |⊆  ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆  ⊎i ∩i   |⊆i ⊎i ∩i   |⊆  ⊎  ∩    |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆  ⊎i ∩i   |⊆i ⊎  ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎  ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎  ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆  ⊎  ∩    |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `VPolygon`                    |⊆i ⊎i      |⊆i ⊎i ∩i C |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i C |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i   |⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i ∩i Ci|-          |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i   |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `VPolytope`                   |⊆i ⊎i      |⊆i ⊎i ∩i C |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩    |⊆i ⊎i ∩  C |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i   |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩  Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `ZeroSet`                     |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Zonotope`                    |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i C |⊆i ⊎i ∩i   |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎       |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i Ci|⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i Ci|⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i Ci|⊆i ⊎  ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i Ci|⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
|                               |           |           |           |           |           |           |           |           |           |           |           |           |           |           |   ⊎       |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |
| **Lazy set operation types**  |           |           |           |           |           |           |           |           |           |           |           |           |           |           |   ⊎       |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |           |
| `CartesianProduct`            |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `CartesianProductArray`       |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆  ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `ConvexHull`                  |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `ConvexHullArray`             |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `ExponentialMap`              |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `ExponentialProjectionMap`    |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Intersection`                |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `IntersectionArray`           |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `LinearMap`                   |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `MinkowskiSum`                |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `MinkowskiSumArray`           |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `CachedMinkowskiSumArray`     |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `ResetMap`                    |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `SymmetricIntervalHull`       |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `Translation`                 |   ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i      |   ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i      |⊆i ⊎i      |⊆i ⊎i ∩i   |⊆i ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |⊆i ⊎i      |   ⊎i      |   ⊎i ∩i   |   ⊎i ∩i   |⊆i ⊎i      |
| `UnionSet`                    |⊆  ⊎  ∩    |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |   ⊎       |   ⊎       |           |
| `UnionSetArray`               |⊆  ⊎  ∩    |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |⊆i ⊎i ∩i   |   ⊎       |   ⊎       |           |
| `Complement`                  |   ⊎       |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |   ⊎i      |           |           |           |
